@@ -12,14 +12,14 @@ module Foundation.Check.Gen
     , genWithParams
     ) where
 
-import           Foundation.Primitive.Imports
+import           Basement.Imports
 import           Foundation.Collection
 import           Foundation.Random
+import qualified Foundation.Random.XorShift as XorShift
 import           Foundation.String
 import           Foundation.Numerical
 import           Foundation.Hashing.SipHash
 import           Foundation.Hashing.Hasher
-import qualified Foundation.Array.Unboxed as A
 
 data GenParams = GenParams
     { genMaxSizeIntegral :: Word -- maximum number of bytes
@@ -27,29 +27,23 @@ data GenParams = GenParams
     , genMaxSizeString   :: Word -- maximum number of chars
     }
 
-newtype GenRng = GenRng RNGv1
+newtype GenRng = GenRng XorShift.State
 
 type GenSeed = Word64
 
 genRng :: GenSeed -> [String] -> (Word64 -> GenRng)
-genRng seed groups = \iteration -> genRngNewNoFail $ A.unsafeRecast $ fromList [w1,w2,w3,iteration]
+genRng seed groups = \iteration -> GenRng $ XorShift.initialize rngSeed (rngSeed * iteration)
   where
-    w1 = rngSeed
-    w2 = rngSeed * 2
-    w3 = rngSeed * 4
-
     (SipHash rngSeed) = hashEnd $ hashMixBytes hashData iHashState
     hashData = toBytes UTF8 $ intercalate "::" groups
     iHashState :: Sip1_3
     iHashState = hashNewParam (SipKey seed 0x12345678)
 
-genRngNewNoFail :: A.UArray Word8 -> GenRng
-genRngNewNoFail = maybe (error "impossible") GenRng . randomNewFrom
-
 genGenerator :: GenRng -> (GenRng, GenRng)
 genGenerator (GenRng rng) =
-    let (newSeed, rngNext) = randomGenerate 32 rng
-     in (genRngNewNoFail newSeed, GenRng rngNext)
+    let (newSeed1, rngNext) = randomGenerateWord64 rng
+        (newSeed2, rngNext') = randomGenerateWord64 rngNext
+     in (GenRng $ XorShift.initialize newSeed1 newSeed2, GenRng rngNext')
 
 -- | Generator monad
 newtype Gen a = Gen { runGen :: GenRng -> GenParams -> a }
