@@ -8,19 +8,21 @@
 -- Different collections (list, vector, string, ..) unified under 1 API.
 -- an API to rules them all, and in the darkness bind them.
 --
-{-# LANGUAGE DefaultSignatures #-}
 {-# LANGUAGE FlexibleInstances #-}
 module Foundation.Collection
     ( BoxedZippable(..)
     , Element
     , InnerFunctor(..)
     , Foldable(..)
+    , Fold1able(..)
     , Mappable(..)
     , traverse_
     , mapM_
     , forM
     , forM_
     , Collection(..)
+    , and
+    , or
     , NonEmpty
     , getNonEmpty
     , nonEmpty
@@ -32,6 +34,7 @@ module Foundation.Collection
     , KeyedCollection(..)
     , Zippable(..)
     , Buildable(..)
+    , build_
     , Builder(..)
     , BuildingState(..)
     , Copy(..)
