@@ -18,6 +18,8 @@
 --
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE ExistentialQuantification #-}
+{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE GeneralizedNewtypeDeriving #-}
 module Foundation.Collection.Collection
     ( Collection(..)
     -- * NonEmpty Property
@@ -30,15 +32,17 @@ module Foundation.Collection.Collection
     , or
     ) where
 
-import           Foundation.Internal.Base hiding (and)
-import           Foundation.Primitive.Types.OffsetSize
+import           Basement.Compat.Base hiding (and)
+import           Basement.Types.OffsetSize
+import           Basement.Types.AsciiString
+import           Basement.Exception (NonEmptyCollectionIsEmpty(..))
 import           Foundation.Collection.Element
-import           Foundation.Collection.NonEmpty
+import           Basement.NonEmpty
 import qualified Data.List
-import qualified Foundation.Primitive.Block as BLK
-import qualified Foundation.Array.Unboxed as UV
-import qualified Foundation.Array.Boxed as BA
-import qualified Foundation.String.UTF8 as S
+import qualified Basement.Block as BLK
+import qualified Basement.UArray as UV
+import qualified Basement.BoxedArray as BA
+import qualified Basement.String as S
 
 -- | Smart constructor to create a NonEmpty collection
 --
@@ -53,16 +57,9 @@ nonEmpty c
 -- and return an asynchronous error if it is.
 nonEmpty_ :: Collection c => c -> NonEmpty c
 nonEmpty_ c
-    | null c    = error "nonEmpty_: assumption failed: collection is empty. consider using nonEmpty and adding proper cases"
+    | null c    = throw NonEmptyCollectionIsEmpty
     | otherwise = NonEmpty c
 
-type instance Element (NonEmpty a) = Element a
-
-instance Collection c => IsList (NonEmpty c) where
-    type Item (NonEmpty c) = Item c
-    toList   = toList . getNonEmpty
-    fromList = nonEmpty_ . fromList
-
 nonEmptyFmap :: Functor f => (a -> b) -> NonEmpty (f a) -> NonEmpty (f b)
 nonEmptyFmap f (NonEmpty l) = NonEmpty (fmap f l)
 
@@ -138,7 +135,7 @@ instance Collection (BA.Array ty) where
     all     = BA.all
     any     = BA.any
 
-
+deriving instance Collection AsciiString
 
 instance Collection S.String where
     null = S.null
