@@ -10,18 +10,20 @@
 --
 {-# LANGUAGE FlexibleInstances     #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
-
+{-# LANGUAGE StandaloneDeriving    #-}
+{-# LANGUAGE GeneralizedNewtypeDeriving #-}
 module Foundation.Collection.Zippable
     ( BoxedZippable(..)
     , Zippable(..)
     ) where
 
-import qualified Foundation.Array.Unboxed as UV
-import qualified Foundation.Array.Boxed as BA
-import qualified Foundation.String.UTF8 as S
+import qualified Basement.UArray as UV
+import qualified Basement.BoxedArray as BA
+import qualified Basement.String as S
 import           Foundation.Collection.Element
 import           Foundation.Collection.Sequential
-import           Foundation.Internal.Base
+import           Basement.Compat.Base
+import           Basement.Types.AsciiString(AsciiString(..))
 import qualified Prelude
 import           GHC.ST
 
@@ -97,6 +99,8 @@ instance Zippable S.String where
       go _  _        []       = return ()
       go f' (a':as') (b':bs') = S.builderAppend (f' a' b') >> go f' as' bs'
 
+deriving instance Zippable AsciiString
+
 class Zippable col => BoxedZippable col where
 
   -- | 'zip' takes two collections and returns a collections of corresponding
