@@ -1,10 +1,12 @@
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE ExistentialQuantification #-}
 {-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE TypeFamilies #-}
 module Test.Foundation.Bits
     ( tests
     ) where
 
+import Basement.Cast
 import Foundation.Bits
 import Foundation.Check
 import Foundation
@@ -16,7 +18,7 @@ instance Arbitrary Shifter where
     arbitrary = Shifter . applyMod <$> arbitrary
       where applyMod i = abs i `mod` 256
 
-testBits :: forall a . (Integral a, IsIntegral a, Bits a, Show a, Eq a, Arbitrary a, Typeable a)
+testBits :: forall a . (Additive a, Bounded a, Difference a ~ a, Integral a, IsIntegral a, Bits a, Show a, Subtractive a, Eq a, Arbitrary a, Typeable a)
          => String
          -> Proxy a
          -> Gen a
@@ -26,6 +28,21 @@ testBits n _ _ = Group n
         (a `shiftR` i) === convertBack (toInteger a `shiftR` i)
     , Property "shiftL" $ \(a :: a) (Shifter i) ->
         (a `shiftL` i) === convertBack (toInteger a `shiftL` i)
+    , Property "maxBound value" $ \(a :: a) ->
+        case bitSizeMaybe a of
+          Just bs ->
+            let actualMaxBound :: a
+                actualMaxBound = maxBound
+                expectedMaxBound :: Integer
+                expectedMaxBound = 2^(cast bs :: Word) - (1 :: Integer)
+            in toInteger actualMaxBound === expectedMaxBound
+          Nothing -> propertyFail "Expected FiniteBits"
+    , Property "complement maxBound" $
+        complement 0 === (maxBound :: a)
+    , Property "overflow maxBound" $
+        maxBound + 1 === (0 :: a)
+    , Property "underflow zero" $
+        (0 :: a) - 1 === maxBound
     ]
   where
     convertBack x
